← Back to team overview

openlp-core team mailing list archive

[Merge] lp:~googol/openlp/vlc into lp:openlp

 

Andreas Preikschat has proposed merging lp:~googol/openlp/vlc into lp:openlp.

Requested reviews:
  OpenLP Core (openlp-core)

For more details, see:
https://code.launchpad.net/~googol/openlp/vlc/+merge/162038

Hello,

- updated vlc.py
-- 
https://code.launchpad.net/~googol/openlp/vlc/+merge/162038
Your team OpenLP Core is requested to review the proposed merge of lp:~googol/openlp/vlc into lp:openlp.
=== modified file 'openlp/core/ui/media/vendor/vlc.py'
--- openlp/core/ui/media/vendor/vlc.py	2013-04-02 07:32:58 +0000
+++ openlp/core/ui/media/vendor/vlc.py	2013-05-02 07:23:33 +0000
@@ -48,7 +48,7 @@
 from inspect import getargspec
 
 __version__ = "N/A"
-build_date  = "Mon Apr  1 23:47:38 2013"
+build_date  = "Mon Apr 29 12:17:29 2013"
 
 if sys.version_info[0] > 2:
     str = str
@@ -3351,6 +3351,39 @@
                     ctypes.c_char_p, ctypes.c_uint)
     return f(event_type)
 
+def libvlc_log_get_context(ctx):
+    '''Gets debugging informations about a log message: the name of the VLC module
+    emitting the message and the message location within the source code.
+    The returned module name and file name will be NULL if unknown.
+    The returned line number will similarly be zero if unknown.
+    @param ctx: message context (as passed to the @ref libvlc_log_cb callback).
+    @return: module module name storage (or NULL), file source code file name storage (or NULL), line source code file line number storage (or NULL).
+    @version: LibVLC 2.1.0 or later.
+    '''
+    f = _Cfunctions.get('libvlc_log_get_context', None) or \
+        _Cfunction('libvlc_log_get_context', ((1,), (2,), (2,), (2,),), None,
+                    None, Log_ptr, ListPOINTER(ctypes.c_char_p), ListPOINTER(ctypes.c_char_p), ctypes.POINTER(ctypes.c_uint))
+    return f(ctx)
+
+def libvlc_log_get_object(ctx, id):
+    '''Gets VLC object informations about a log message: the type name of the VLC
+    object emitting the message, the object header if any and a temporaly-unique
+    object identifier. These informations are mainly meant for B{manual}
+    troubleshooting.
+    The returned type name may be "generic" if unknown, but it cannot be NULL.
+    The returned header will be NULL if unset; in current versions, the header
+    is used to distinguish for VLM inputs.
+    The returned object ID will be zero if the message is not associated with
+    any VLC object.
+    @param ctx: message context (as passed to the @ref libvlc_log_cb callback).
+    @return: name object name storage (or NULL), header object header (or NULL), line source code file line number storage (or NULL).
+    @version: LibVLC 2.1.0 or later.
+    '''
+    f = _Cfunctions.get('libvlc_log_get_object', None) or \
+        _Cfunction('libvlc_log_get_object', ((1,), (2,), (2,), (1,),), None,
+                    None, Log_ptr, ListPOINTER(ctypes.c_char_p), ListPOINTER(ctypes.c_char_p), ctypes.POINTER(ctypes.c_uint))
+    return f(ctx, id)
+
 def libvlc_log_unset(p_instance):
     '''Unsets the logging callback for a LibVLC instance. This is rarely needed:
     the callback is implicitly unset when the instance is destroyed.
@@ -5827,7 +5860,7 @@
 #  libvlc_printerr
 #  libvlc_set_exit_handler
 
 # 15 function(s) not wrapped as methods:
 #  libvlc_audio_output_device_list_release
 #  libvlc_audio_output_list_release
 #  libvlc_clearerr
@@ -5838,6 +5871,8 @@
 #  libvlc_get_changeset
 #  libvlc_get_compiler
 #  libvlc_get_version
+#  libvlc_log_get_context
+#  libvlc_log_get_object
 #  libvlc_media_tracks_release
 #  libvlc_module_description_list_release
 #  libvlc_new
@@ -5827,7 +5860,7 @@
 #  libvlc_set_exit_handler
 
-# 15 function(s) not wrapped as methods:
+# 17 function(s) not wrapped as methods:
 #  libvlc_audio_output_device_list_release
 #  libvlc_audio_output_list_release


Follow ups